@@ -72,7 +72,10 @@ class Agent(Insight, Channel, Catalog, Dataset):
             self._domain = agent.iloc[0]['domain']
             self._language = agent.iloc[0]['language']
             self._agent_name = agent.iloc[0]['name']
-            self.slug = agent.iloc[0]['slug']
+            if(slug!=''):
+                self.slug=slug
+            else:
+                agent.iloc[0]['slug']
 
         except Exception as ex:
             raise NameError('Agent slug/name/id not exsist or not insert')
@@ -203,7 +206,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
 
 
-    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id=""):
+    def query(self, dataset_slug="", fields:list=[], filters=None, sorted_by=None,  dataset_id="", limit=50):
 
         if(fields==[]):
             print("SELECT FIELDS")
@@ -242,7 +245,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "datasetId": datasetId,
             "fields": fields,
             "sortedBy": sorted_by,
-            "filters": filters
+            "filters": filters,
+            "limit": limit
         }
 
         print(body)
@@ -317,9 +321,9 @@ class Agent(Insight, Channel, Catalog, Dataset):
         list : filters ([{field: {column: "CONTACTS", alias: null, aggregation: null,…}, operator: "EQ", type: "NUMERIC",…}])
         '''
 
-        dataset = self.get_dataset_by_slug(self._agentId, dataset_slug)
+        dataset_id = self.get_dataset_by_slug(self._agentId, dataset_slug)
 
-        if(dataset == None):
+        if(dataset_id == None):
 
             s = requests.Session()
             s.keep_alive = False
@@ -340,12 +344,12 @@ class Agent(Insight, Channel, Catalog, Dataset):
                 logging.error("Please insert a correct dataset slug")
                 return
         else:
-            dataset_id = dataset["id"]
+            dataset_id = dataset_id
 
         if(aliases==[]):
             return self._load_dataset(dataset_id)
 
-        dataset_id = dataset["id"]
+        dataset_id = dataset_id
         url_get = self.smart_insight_url + "/composed_queries?datasetId=" + dataset_id
 
         logging.info("CALLING {}".format(url_get))
@@ -419,8 +423,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response = s.get(url=authentication_url, headers=headers)
         response.raise_for_status()
         r = response.json()
-        if (r["found"]):
-            return r["dataset"]
+        if (r["datasetId"]):
+            return r["datasetId"]
         else:
             return None
 
@@ -589,10 +593,10 @@ class Agent(Insight, Channel, Catalog, Dataset):
     def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
                                   settings: dict = None):
         # Check if dataset exists
-        dataset = self.get_dataset_by_slug(self.slug, slug)
+        dataset_id = self.get_dataset_by_slug(self.slug, slug)
 
         dataframe = dataframe.where(pd.notnull(dataframe), None)
-        if(dataset != None):
+        if(dataset_id != None):
             #If it exists update it
             self.update_dataset(dataframe, dataset_name, slug, icon_url, settings)
         else:
